/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shale.usecases.symbols;

import java.util.Map;

import org.apache.shale.view.AbstractViewController;

/**
 * <p>This view controller manages state outside of the managed beans 
 * associated with the form.  It's purpose is to respond to the loading 
 * of the page and processing the posted events.</p>
 */
public class RegistrationForm extends AbstractViewController {
    
    /**
     * <p>This view controller is scoped in the request. The init method
     * is invoked for each request and the page's state is stored in
     * session scoped beans. The dialog for these session scoped
     * beans are managed through this stateless controller.
     * This separation of view model data and action controller is similar 
     * to Struts Action 1.x.</p> 
     */
    public void init() {
        
        String init = (String) ((Map) getBean("param")).get("init");
        boolean isInit = Boolean.valueOf(init).booleanValue();
        if (isInit) {
            BasicPerson person = new BasicPerson();
            person.setFirstName("Gary");
            person.setLastName("VanMatre");
            setBean("basicPerson", person);
            
            setBean("fullPerson", new FullPerson());
            setBean("businessPerson", new BusinessPerson());
        }
    }
    
    /**
     * <p>Handles action of saving the pages state.</p> 
     */
    public String save() {      
        return "save";
    }
    
}
